@@ -199,6 +199,12 @@ class CreateTairInstanceRequest(RpcRequest):
 	def set_OwnerAccount(self,OwnerAccount):
 		self.add_query_param('OwnerAccount',OwnerAccount)
 
+	def get_GlobalInstanceId(self):
+		return self.get_query_params().get('GlobalInstanceId')
+
+	def set_GlobalInstanceId(self,GlobalInstanceId):
+		self.add_query_param('GlobalInstanceId',GlobalInstanceId)
+
 	def get_VpcId(self):
 		return self.get_query_params().get('VpcId')
 
